@@ -3,7 +3,10 @@ import osso
 import gtk
 import os
 import csv
-import gnomevfs
+try:
+  from gnome import gnomevfs
+except ImportError:
+  import gnomevfs
 
 # This program is based on sample taken from :
 # http://pymaemo.garage.maemo.org/documentation/pymaemo_tutorial/python_maemo_howto.html#link18
